<?php
namespace Controller;

use Zeedhi\DevOps\Util\Environment;
use Zeedhi\DevOps\Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\DataSet as RequestDataset;
use Zeedhi\Framework\DTO\Request\Filter as RequestFilter;

class BranchProductQuery extends \Generated\Controller\BranchProductQuery {

    public function __construct(Manager $dataSourceManager, Environment $environment) {
        parent::__construct($dataSourceManager);
        $this->environment = $environment;
    }

    /**
     * @param RequestDataset $request
     * @param DTO\Response $response
     * @param bool $showMessage
     */
    public function save(DTO\Request $request, DTO\Response $response, $showMessage = true) {
        $dataSet     = $request->getDataSet();
        $rows = $dataSet->getRows();
        $showMessage =Utilities::verifyShowMessage($dataSet);
        $organizationId = $this->environment->getOrganizationId();
        foreach ($rows as &$row) {
            $row['ORGANIZATION_ID'] = $organizationId;
        }
        $dataSet = new DataSet($dataSet->getDataSourceName(),$rows);
        $request = new RequestDataset($dataSet,$request->getMethod(),$request->getRoutePath(),$request->getUserId());
        parent::save($request, $response, $showMessage);
    }

    public function delete(DTO\Request $request, DTO\Response $response, $showMessage = true) {
        $dataSet     = $request->getDataSet();
        $showMessage = Utilities::verifyShowMessage($dataSet);
        parent::delete($request, $response, $showMessage);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response){
        $request->getFilterCriteria()->addCondition("ORGANIZATION_ID", "=", $this->environment->getCurrentOrganizationId());
        parent::find($request, $response);
    }
}